@@ -9,14 +9,21 @@ import sys
 import threading
 from ast import PyCF_ONLY_AST
 from inspect import Parameter
-from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple
+from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple, Union
 
 import docstring_to_markdown
 import jedi.api.errors
 import jedi.inference.references
 import jedi.settings
 from jedi import Project, Script
-from jedi.api.classes import BaseName, Completion, Name, ParamName, Signature
+from jedi.api.classes import (
+    BaseName,
+    BaseSignature,
+    Completion,
+    Name,
+    ParamName,
+    Signature,
+)
 from lsprotocol.types import (
     CompletionItem,
     CompletionItemKind,
@@ -32,7 +39,7 @@ from lsprotocol.types import (
     SymbolInformation,
     SymbolKind,
 )
-from pygls.workspace import Document
+from pygls.workspace import TextDocument
 
 from .initialization_options import HoverDisableOptions, InitializationOptions
 from .type_map import get_lsp_completion_type, get_lsp_symbol_type
@@ -85,7 +92,7 @@ def debounce(
 
 
 def _jedi_debug_function(
-    color: str,  # pylint: disable=unused-argument
+    color: str,
     str_out: str,
 ) -> None:
     """Jedi debugging function that prints to stderr.
@@ -95,7 +102,7 @@ def _jedi_debug_function(
     print(str_out, file=sys.stderr)
 
 
-def set_jedi_settings(  # pylint: disable=invalid-name
+def set_jedi_settings(
     initialization_options: InitializationOptions,
 ) -> None:
     """Sets jedi settings."""
@@ -113,7 +120,7 @@ def set_jedi_settings(  # pylint: disable=invalid-name
         jedi.set_debug_function(func_cb=_jedi_debug_function)
 
 
-def script(project: Optional[Project], document: Document) -> Script:
+def script(project: Optional[Project], document: TextDocument) -> Script:
     """Simplifies getting jedi Script."""
     return Script(code=document.source, path=document.path, project=project)
 
@@ -200,7 +207,6 @@ def lsp_document_symbols(names: List[Name]) -> List[DocumentSymbol]:
     accessible with dot notation are removed from display. See comments
     inline for cleaning steps.
     """
-    # pylint: disable=too-many-branches
     _name_lookup: Dict[Name, DocumentSymbol] = {}
     results: List[DocumentSymbol] = []
     for name in names:
@@ -299,21 +305,19 @@ def lsp_python_diagnostic(uri: str, source: str) -> Optional[Diagnostic]:
         compile(source, uri, "exec", PyCF_ONLY_AST)
         return None
     except SyntaxError as err:
-        column = err.offset - 1 if err.offset is not None else 0
-        line = err.lineno - 1 if err.lineno is not None else 0
-
+        column = max(0, err.offset - 1 if err.offset is not None else 0)
+        line = max(0, err.lineno - 1 if err.lineno is not None else 0)
         _until_column = getattr(err, "end_offset", None)
         _until_line = getattr(err, "end_lineno", None)
-
-        until_column = (
-            _until_column - 1 if _until_column is not None else column + 1
+        until_column = max(
+            0, _until_column - 1 if _until_column is not None else column + 1
+        )
+        until_line = max(
+            0, _until_line - 1 if _until_line is not None else line
         )
-        until_line = _until_line - 1 if _until_line is not None else line
-
         if (line, column) >= (until_line, until_column):
             until_column, until_line = column, line
             column = 0
-
         return Diagnostic(
             range=Range(
                 start=Position(line=line, character=column),
@@ -420,7 +424,7 @@ _POSITION_PARAMETERS = {
 _PARAM_NAME_IGNORE = {"/", "*"}
 
 
-def get_snippet_signature(signature: Signature) -> str:
+def get_snippet_signature(signature: Union[Signature, BaseSignature]) -> str:
     """Return the snippet signature."""
     params: List[ParamName] = signature.params
     if not params:
@@ -454,7 +458,6 @@ def is_import(script_: Script, line: int, column: int) -> bool:
     completions, without any text, which will may cause issues for users with
     manually triggered completions.
     """
-    # pylint: disable=protected-access
     tree_name = script_._module_node.get_name_of_position((line, column))
     if tree_name is None:
         return False
@@ -478,7 +481,7 @@ def clear_completions_cache() -> None:
     _MOST_RECENT_COMPLETIONS.clear()
 
 
-def lsp_completion_item(  # pylint: disable=too-many-arguments
+def lsp_completion_item(
     completion: Completion,
     char_before_cursor: str,
     enable_snippets: bool,
@@ -516,7 +519,7 @@ def lsp_completion_item(  # pylint: disable=too-many-arguments
 
     try:
         snippet_signature = get_snippet_signature(signatures[0])
-    except Exception:  # pylint: disable=broad-except
+    except Exception:
         return completion_item
     new_text = completion_name + snippet_signature
     completion_item.insert_text = new_text
@@ -529,11 +532,6 @@ def _md_bold(value: str, markup_kind: MarkupKind) -> str:
     return f"**{value}**" if markup_kind == MarkupKind.Markdown else value
 
 
-def _md_italic(value: str, markup_kind: MarkupKind) -> str:
-    """Add italic surrounding when markup_kind is markdown."""
-    return f"*{value}*" if markup_kind == MarkupKind.Markdown else value
-
-
 def _md_text(value: str, markup_kind: MarkupKind) -> str:
     """Surround a markdown string with a Python fence."""
     return (
@@ -575,7 +573,7 @@ def convert_docstring(docstring: str, markup_kind: MarkupKind) -> str:
             return docstring_to_markdown.convert(docstring_stripped).strip()
         except docstring_to_markdown.UnknownFormatError:
             return _md_text(docstring_stripped, markup_kind)
-        except Exception as error:  # pylint: disable=broad-except
+        except Exception as error:
             result = (
                 docstring_stripped
                 + "\n"
@@ -653,7 +651,6 @@ def hover_text(
     initialization_options: InitializationOptions,
 ) -> Optional[str]:
     """Get a hover string from a list of names."""
-    # pylint: disable=too-many-branches
     if not names:
         return None
     name = names[0]
